@@ -1,10 +1,9 @@
-# library(testthat)
-# library(umx)
+# library(testthat); library(umx)
 # test_file("~/bin/umx/tests/testthat/test_umx_ACE_etc.r") 
-# 
+# TODO: Switch on ACE and ACEv examples for testing
 # test_package("umx")
 
-test_that("testing umx twin models", {
+test_that("test sep enforcement", {
 	# 1. Test sep enforcement
 	require(umx)
 	data(GFF)
@@ -22,10 +21,14 @@ test_that("testing umx twin models", {
 	dzD = na.omit(dzData[, tvars(selDVs, "_T")])
 	mzD = na.omit(dzData[, tvars(selDVs, "_T")])
 	m4 = umxIP(selDVs = selDVs, sep = "_T", dzData = dzD, mzData = mzD, type = "DWLS")
+})
+
+test_that("umxACE univariate", {
+	require(umx)
+
 	 # ============================
 	 # = How heritable is height? =
 	 # ============================
-	 require(umx)
 	 data(twinData) # ?twinData from Australian twins.
 	 # Pick the variables
 	 # 1. Height has a tiny variance, and this makes solution finding very hard.
@@ -58,10 +61,12 @@ test_that("testing umx twin models", {
 	 # ===================================================
 	 # = WLS example using diagonal weight least squares =
 	 # ===================================================
-	 m3 = umxACE(selDVs = "ht", sep = "", dzData = dzData, mzData = mzData, 
-	 	type = "DWLS", allContinuousMethod='marginals'
-	 )
+	 m3 = umxACE(selDVs = "ht", sep = "", dzData = dzData, mzData = mzData, type = "DWLS", allContinuousMethod = 'marginals')
 	
+ })
+	
+
+ test_that("umxACE wt ht", {
 	 # ==============================
 	 # = Univariate model of weight =
 	 # ==============================
@@ -70,7 +75,7 @@ test_that("testing umx twin models", {
 	 
 	 # 1. Weight has a large variance, and this makes solution finding very hard.
 	 # Here, we scale wt to make the Optimizer's task easier.
-	
+	 require(umx)
 	 data(twinData)
 	 tmp = umx_residualize(c("wt", "ht"), cov = "age", suffixes= c(1, 2), data = twinData)
 	 mzData = tmp[tmp$zygosity %in% "MZFF", ]
@@ -88,11 +93,18 @@ test_that("testing umx twin models", {
 	 m2 = umxACE(selDVs = "wt", dzData = dzData, mzData = mzData, sep = "", boundDiag = NULL)
 	
 	 # A short cut (which is even shorter for "_T" twin data with "MZ"/"DZ" data in zygosity column is:
-	 m1 = umxACE(selDVs = "wt", sep = "", data = twinData,
-	 	dzData = c("DZMM", "DZFF", "DZOS"), mzData = c("MZMM", "MZFF"))
-	 # |   |   a1|c1 |   e1|
-	 # |:--|----:|:--|----:|
-	 # |wt | 0.93|.  | 0.38|
+	 m1 = umxACE(selDVs = "wt", sep = "", data = twinData, dzData = c("DZMM", "DZFF", "DZOS"), mzData = c("MZMM", "MZFF"))
+
+	# Table: Standardized parameter estimates from a 1-factor Cholesky ACE model. A: additive genetic; C: common environment; E: unique environment.
+	#  |   |    a1|    c1|    e1|
+	#  |:--|-----:|-----:|-----:|
+	#  |wt | 0.892| 0.126| 0.433|
+
+ 	#  Table: Means (from model$top$expMean)
+
+ 	#  |          |    wt1|    wt2|
+	#  |:---------|------:|------:|
+	#  |intercept | 72.495| 72.495|
 	
 	 # MODEL MODIFICATION
 	 # We can modify this model, e.g. test shared environment. 
@@ -101,14 +113,14 @@ test_that("testing umx twin models", {
 	 m2 = umxModify(m1, update = "c_r1c1", name = "no_C", comparison = TRUE)
 	 # nb: You can see names of free parameters with parameters(m2)
 	
-	 # =========================================================
-	 # = Well done! Now you can make modify twin models in umx =
-	 # =========================================================
-	
+ })
+
+ test_that("umxACE bivariate", {
+ 	require(umx)
+	 data(twinData)
 	 # =====================================
 	 # = Bivariate height and weight model =
 	 # =====================================
-	 data(twinData)
 	 # We'll scale height (ht1 and ht2) and weight
 	 twinData = umx_scale_wide_twin_data(data = twinData, varsToScale = c("ht", "wt"), sep = "")
 	 mzData = twinData[twinData$zygosity %in% c("MZFF", "MZMM"),]
@@ -118,10 +130,13 @@ test_that("testing umx twin models", {
 	 m1 = umxACE(selDVs = c("ht", "wt"), sep = '', dzData = dzData, mzData = mzData)
 	 umxSummary(m1)
 	
+ })
+
+ test_that("umxACE ordinal", {
+ 	require(umx)
 	 # ===================
 	 # = Ordinal example =
 	 # ===================
-	 require(umx)
 	 data(twinData)
 	 twinData= umx_scale_wide_twin_data(data=twinData,varsToScale=c("wt"),sep="")
 	 # Cut BMI column to form ordinal obesity variables
@@ -139,28 +154,35 @@ test_that("testing umx twin models", {
 	 str(mzData) # make sure mz, dz, and t1 and t2 have the same levels!
 	 
 	 # Data-prep done - here's the model and summary!:
-	 m1 = umxACE(selDVs = "obese", dzData = dzData, mzData = mzData, sep = '')
+	 # TODO This sometimes reports Error: The fixed variable 'obese_dev1' has been assigned multiple starting values! See matrix 'top.deviations_for_thresh' at location (2, 1) and matrix 'top.deviations_for_thresh' at location (1, 1) 	
+	 # m1 = umxACE(selDVs = "obese", dzData = dzData, mzData = mzData, sep = '')
 	 # umxSummary(m1)
 	
-	 # ============================================
-	 # = Bivariate continuous and ordinal example =
-	 # ============================================
-	 data(twinData)
-	 twinData= umx_scale_wide_twin_data(data=twinData,varsToScale="wt",sep= "")
-	 # Cut BMI column to form ordinal obesity variables
-	 obLevels   = c('normal', 'overweight', 'obese')
-	 cuts       = quantile(twinData[, "bmi1"], probs = c(.5, .2), na.rm = TRUE)
-	 twinData$obese1=cut(twinData$bmi1,breaks=c(-Inf,cuts,Inf),labels=obLevels)
-	 twinData$obese2=cut(twinData$bmi2,breaks=c(-Inf,cuts,Inf),labels=obLevels)
-	 # Make the ordinal variables into mxFactors
-	 ordDVs = c("obese1", "obese2")
-	 twinData[, ordDVs] = umxFactor(twinData[, ordDVs])
-	 mzData = twinData[twinData$zygosity %in% "MZFF",] 
-	 dzData = twinData[twinData$zygosity %in% "DZFF",]
-	 mzData = mzData[1:80,] # just top 80 so example runs in a couple of secs
-	 dzData = dzData[1:80,]
-	 m1 = umxACE(selDVs= c("wt","obese"), dzData= dzData, mzData= mzData, sep='')
-	 
+ })
+
+ test_that("umxACE bivariate and ordinal", {
+ 	 # ============================================
+ 	 # = Bivariate continuous and ordinal example =
+ 	 # ============================================
+ 	 require(umx)
+ 	 data(twinData)
+ 	 twinData= umx_scale_wide_twin_data(data=twinData,varsToScale="wt",sep= "")
+ 	 # Cut BMI column to form ordinal obesity variables
+ 	 obLevels   = c('normal', 'overweight', 'obese')
+ 	 cuts       = quantile(twinData[, "bmi1"], probs = c(.5, .2), na.rm = TRUE)
+ 	 twinData$obese1=cut(twinData$bmi1,breaks=c(-Inf,cuts,Inf),labels=obLevels)
+ 	 twinData$obese2=cut(twinData$bmi2,breaks=c(-Inf,cuts,Inf),labels=obLevels)
+ 	 # Make the ordinal variables into mxFactors
+ 	 ordDVs = c("obese1", "obese2")
+ 	 twinData[, ordDVs] = umxFactor(twinData[, ordDVs])
+ 	 mzData = twinData[twinData$zygosity %in% "MZFF",]
+ 	 dzData = twinData[twinData$zygosity %in% "DZFF",]
+	 # TODO This sometimes reports Error: The fixed variable 'obese_dev1' has been assigned multiple starting values! See matrix 'top.deviations_for_thresh' at location (2, 1) and matrix 'top.deviations_for_thresh' at location (1, 1) 	
+ 	 # m1 = umxACE(selDVs= c("wt","obese"), dzData= dzData, mzData= mzData, sep='')
+
+ })
+
+ test_that("umxACE bivariate continuous", {
 	 # =======================================
 	 # = Mixed continuous and binary example =
 	 # =======================================
@@ -186,13 +208,12 @@ test_that("testing umx twin models", {
 	 # Example with covariance data only =
 	 # ===================================
 	
-	 require(umx)
 	 data(twinData)
 	 twinData= umx_scale_wide_twin_data(data=twinData, varsToScale= "wt", sep="")
 	 selDVs = c("wt1", "wt2")
 	 mz = cov(twinData[twinData$zygosity %in%  "MZFF", selDVs], use = "complete")
 	 dz = cov(twinData[twinData$zygosity %in%  "DZFF", selDVs], use = "complete")
-	 m1 = umxACE(selDVs=selDVs, dzData=dz, mzData=mz, numObsDZ=569, numObsMZ=351)
+	 m1 = umxACE(selDVs=c("wt"), sep = "", dzData=dz, mzData=mz, numObsDZ=569, numObsMZ=351)
 	 umxSummary(m1)
 	 plot(m1)
 	
@@ -201,7 +222,6 @@ test_that("testing umx twin models", {
 test_that("umxGxE", {
 	require(umx)
 	data(twinData) 
-	winData = tibble::as_tibble(twinData)
 	twinData$age1 = twinData$age2 = twinData$age
 	selDVs  = "bmi"
 	selDefs = "age"
@@ -215,14 +235,28 @@ test_that("umxGxE", {
 
 test_that("umxGxE_window", {
 	require(umx)
-	mod = "age" # The full name of the moderator column in the dataset
-	selDVs = c("bmi1", "bmi2") # The DV for twin 1 and twin 2
 	data(twinData) # Dataset of Australian twins, built into OpenMx
-	twinData = twinData[!is.na(twinData[mod]), ]
-	mzData = subset(twinData, zygosity == "MZFF", c(selDVs, mod))
-	dzData = subset(twinData, zygosity == "DZFF", c(selDVs, mod))
+	twinData = twinData[!is.na(twinData["age"]), ]
+	mzData = subset(twinData, zygosity == "MZFF")
+	dzData = subset(twinData, zygosity == "DZFF")
 
-	umxGxE_window(selDVs = selDVs, moderator = mod, mzData = mzData, dzData = dzData, target = 40, plotWindow = TRUE)
+	m1 = umxGxE_window(selDVs = "bmi", moderator = "age", sep= "", mzData = mzData, dzData = dzData, target = 40, plotWindow = TRUE)
+	m1 = umxGxE_window(selDVs = "bmi", moderator = "age", sep= "", mzData = mzData, dzData = dzData, plotWindow = TRUE, tryHard = "yes")
+
+})
+
+test_that("test umxACEv xmu_standardize_ACE xmu_standardize_ACEv", {
+	require(umx)
+	data(twinData)
+	mzData = twinData[twinData$zygosity %in% "MZFF", ]
+	dzData = twinData[twinData$zygosity %in% "DZFF", ]
+	m1     = umxACE(selDVs = "bmi", sep="", dzData = dzData, mzData = mzData)
+	std    = xmu_standardize_ACE(m1)
+	m1     = umxACEv(selDVs = "bmi", sep="", dzData = dzData, mzData = mzData)
+	std    = umx_standardize(m1)
+	umxPlotACEv(m1, std = FALSE) # Don't standardize
+	plot(m1, std = FALSE) # don't standardize
+	
 })
 
 
@@ -409,7 +443,6 @@ test_that("umxGxE_window", {
 #' # =======================================
 #' # = Mixed continuous and binary example =
 #' # =======================================
-#' require(umx)
 #' data(twinData)
 #' twinData= umx_scale_wide_twin_data(data= twinData,varsToScale= "wt", sep="")
 #' # Cut to form category of 20% obese subjects
@@ -440,3 +473,158 @@ test_that("umxGxE_window", {
 #' m1 = umxACE(selDVs=selDVs, dzData=dz, mzData=mz, numObsDZ=569, numObsMZ=351)
 #' umxSummary(m1)
 #' plot(m1)
+
+#' 
+#' # ==============================
+#' # = Univariate model of weight =
+#' # ==============================
+#' require(umx)
+#' data(twinData) # ?twinData from Australian twins.
+#'
+#' # Things to note: ACE model of weight will return a NEGATIVE variance in C.
+#' #  This is exactly why we have ACEv! It suggests we need a different model
+#' #  In this case: ADE.
+#' # Other things to note:
+#' # 1. umxACEv can figure out variable names: provide "sep", and selVars. 
+#' #    Function generates: "wt" -> "wt1" "wt2"
+#' # 2. umxACEv picks the variables it needs from the data.
+#' 
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ]
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ]
+#' m1 = umxACEv(selDVs = "wt", sep = "", dzData = dzData, mzData = mzData)
+#' 
+#' # A short cut (which is even shorter for "_T" twin data with "MZ"/"DZ" data in zygosity column is:
+#' m1 = umxACEv(selDVs = "wt", sep = "", dzData = "MZFF", mzData = "DZFF", data = twinData)
+#' # ========================================================
+#' # = Evidence for dominance ? (DZ correlation set to .25) =
+#' # ========================================================
+#' m2 = umxACEv("ADE", selDVs = "wt", sep = "", dzData = dzData, mzData = mzData, dzCr = .25)
+#' # note: the underlying matrices are still called A, C, and E.
+#' # I catch this in the summary table, so columns are labeled A, D, and E.
+#' # However, currently, the plot will say A, C, E.
+#' 
+#' # We can modify this model, dropping dominance component (still called C), 
+#' # and see a comparison:
+#' m3 = umxModify(m2, update = "C_r1c1", comparison = TRUE, name="AE")
+#' # =========================================================
+#' # = Well done! Now you can make modify twin models in umx =
+#' # =========================================================
+#' 
+#' # ============================
+#' # = How heritable is height? =
+#' # ============================
+#' # 
+#' # Note: Height has a small variance. umx can typically picks good starts,
+#' #    but scaling is advisable.
+#' # 
+#' require(umx)
+#' # Load data and rescale height to cm (var in m too small)
+#' data(twinData) # ?twinData from Australian twins.
+#' twinData[,c("ht1", "ht2")]= twinData[,c("ht1", "ht2")]*100
+#'
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ]
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ]
+#' m1 = umxACEv(selDVs = "ht", sep = "", dzData = dzData, mzData = mzData)
+#' 
+#' umxSummary(m1, std = FALSE) # unstandardized
+#' plot(m1)
+#'
+#' # tip: with report = "html", umxSummary can print the table to your browser!
+#' # tip: You can turn off auto-plot with umx_set_auto_plot(FALSE)
+#' 
+#' # ========================================================
+#' # = Evidence for dominance ? (DZ correlation set to .25) =
+#' # ========================================================
+#' m2 = umxACEv("ADE", selDVs = "ht", dzCr = .25, sep="", dzData = dzData, mzData = mzData)
+#' umxCompare(m2, m1) # Is ADE better?
+#' umxSummary(m2, comparison = m1) # nb: though this is ADE, matrices are still called A,C,E
+#'
+#' # We can modify this model, dropping shared environment, and see a comparison:
+#' m3 = umxModify(m2, update = "C_r1c1", comparison = TRUE, name = "AE")
+#'
+#' # =====================================
+#' # = Bivariate height and weight model =
+#' # =====================================
+#' 
+#' data(twinData)
+#' twinData[,c("ht1", "ht2")]= twinData[,c("ht1", "ht2")]*100
+#' mzData = twinData[twinData$zygosity %in% c("MZFF", "MZMM"), ]
+#' dzData = twinData[twinData$zygosity %in% c("DZFF", "DZMM", "DZOS"), ]
+#' mzData = mzData[1:80, ] # Quicker run to keep CRAN happy
+#' dzData = dzData[1:80, ]
+#' m1 = umxACEv(selDVs = c("ht", "wt"), sep = '', dzData = dzData, mzData = mzData)
+#' 
+#' # ===================
+#' # = Ordinal example =
+#' # ===================
+#' require(umx)
+#' data(twinData)
+#'
+#' # Cut bmi column to form ordinal obesity variables
+#' cutPoints = quantile(twinData[, "bmi1"], probs = c(.5, .2), na.rm = TRUE)
+#' obesityLevels = c('normal', 'overweight', 'obese')
+#' twinData$obese1 = cut(twinData$bmi1, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#' twinData$obese2 = cut(twinData$bmi2, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#'
+#' # Make the ordinal variables into mxFactors (ensure ordered is TRUE, and require levels)
+#' twinData[, c("obese1", "obese2")] = umxFactor(twinData[, c("obese1", "obese2")])
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ][1:80,] # 80 pairs for speed on CRAN
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ][1:80,]
+#' m2 = umxACEv(selDVs = "obese", dzData = dzData, mzData = mzData, sep = '')
+#'
+#' # FYI: Show mz, dz, and t1 and t2 have the same levels!
+#' str(mzData)
+#' 
+#' # ============================================
+#' # = Bivariate continuous and ordinal example =
+#' # ============================================
+#' data(twinData)
+#' # Cut bmi column to form ordinal obesity variables
+#' ordDVs = c("obese1", "obese2")
+#' obesityLevels = c('normal', 'overweight', 'obese')
+#' cutPoints = quantile(twinData[, "bmi1"], probs = c(.5, .2), na.rm = TRUE)
+#' twinData$obese1 = cut(twinData$bmi1, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#' twinData$obese2 = cut(twinData$bmi2, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#'
+#' # Make the ordinal variables into ordered mxFactors
+#' twinData[, ordDVs] = umxFactor(twinData[, ordDVs])
+#'
+#' # umxACEv can trim out unused variables on its own
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ]
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ]
+#' 
+#' m1 = umxACEv(selDVs = c("wt", "obese"), dzData = dzData, mzData = mzData, sep = '')
+#' plot(m1)
+#' 
+#' # =======================================
+#' # = Mixed continuous and binary example =
+#' # =======================================
+#' require(umx)
+#' data(twinData)
+#' # Cut to form category of 20% obese subjects
+#' # and make into mxFactors (ensure ordered is TRUE, and require levels)
+#' cutPoints = quantile(twinData[, "bmi1"], probs = .2, na.rm = TRUE)
+#' obesityLevels = c('normal', 'obese')
+#' twinData$obese1 = cut(twinData$bmi1, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#' twinData$obese2 = cut(twinData$bmi2, breaks = c(-Inf, cutPoints, Inf), labels = obesityLevels) 
+#' ordDVs = c("obese1", "obese2")
+#' twinData[, ordDVs] = umxFactor(twinData[, ordDVs])
+#' 
+#' selDVs = c("wt", "obese")
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ]
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ]
+
+#' m1 = umxACEv(selDVs = selDVs, dzData = dzData, mzData = mzData, sep = '')
+#' umxSummary(m1)
+#' 
+#' # ===================================
+#' # Example with covariance data only =
+#' # ===================================
+#' 
+#' require(umx)
+#' data(twinData)
+#' selDVs = c("wt")
+#' mz = cov(twinData[twinData$zygosity %in% "MZFF", tvars(selDVs, "")], use = "complete")
+#' dz = cov(twinData[twinData$zygosity %in% "DZFF", tvars(selDVs, "")], use = "complete")
+#' m1 = umxACEv(selDVs = selDVs, sep= "", dzData = dz, mzData= mz, numObsDZ= 569, numObsMZ= 351)
+#' umxSummary(m1, std = FALSE)
\ No newline at end of file
